@@ -1,29 +1,52 @@
 import requests
 import requestsWS
-import time
+import undetected_chromedriver as uc
+from selenium.webdriver.common.by import By
 from decimal import *
 
-def round_down(value, decimals): # https://stackoverflow.com/questions/41383787/round-down-to-2-decimal-in-python
+
+def round_down(value, decimals):  # https://stackoverflow.com/questions/41383787/round-down-to-2-decimal-in-python
     with localcontext() as ctx:
         ctx.rounding = ROUND_DOWN
         return round(value, decimals)
 
+
 class Hotbit:
     def __init__(self, auth):
-        self.auth = auth
+        # create session and WS session
+        ## create driver with selenium/undetected_chromedriver
+        print("Solving Cloudflare - allow up to 5s")
+        driver = uc.Chrome()
+        driver.implicitly_wait(15)
+        driver.get("https://www.hotbit.io/")
+        driver.find_element(By.XPATH,
+                            '/html/body/div[1]/div[1]/div[1]/div/div[1]/p[1]')  # waits till cf is solved and the Hotbit Title is visable
+
+        ## get cookies and user_agent
+        brCookies = driver.get_cookies()
+        ua = driver.execute_script("return navigator.userAgent")
+
+        ## filter out the cf_clearance cookie
+        cf_cookie = [cookie for cookie in brCookies if cookie['name'] == 'cf_clearance'][0]['value']
+        self.cookies = {"cf_clearance": cf_cookie}
+        self.defaultHeaders = {"user-agent": ua}
+        driver.close()
+        print('Successfully solved Cloudflare')
 
         self.session = requests.Session()
         self.sessionWS = requestsWS.Session()
 
+        # add cf and hotbit-account cookies
         for key, value in auth.items():
-            self.session.cookies.set(key, value, domain="hotbit.pro")
+            self.session.cookies.set(key, value, domain="hotbit.io")
 
-        self.defaultHeaders = {
-            "referer": "https://www.hotbit.pro/",
-            "user-agent": "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/98.0.4758.102 Safari/537.36",
-        }
-        resp = self.session.get("https://www.hotbit.pro/v1/info?platform=web", headers=self.defaultHeaders)
-        if resp.json()["Msg"] != "success" or resp.status_code != 200:
+        # set defaultHeader, cookies, check status of first get request and assign params for openingPayload
+        self.session.headers['User-Agent'] = ua
+        self.session.headers['referer'] = 'https://www.hotbit.io/dw'
+        resp = self.session.get('https://www.hotbit.io/v1/info?platform=web', headers=self.defaultHeaders,
+                                cookies=self.cookies)
+
+        if resp.json()['Msg'] != 'success' or resp.status_code != 200:
             print(resp.content)
             exit(resp.status_code)
 
@@ -37,7 +60,8 @@ class Hotbit:
             "method": "server.auth2",
             "params": [self.uid, time, whereFrom, sign]
         }
-        self.wsPost('wss://ws.hotbit.io/', self.sessionWS, json=self.openingPayload, encryption="gzip", identifiers={"id": 300})
+        self.wsPost('wss://ws.hotbit.io/', self.sessionWS, json=self.openingPayload, encryption="gzip",
+                    identifiers={"id": 300})
 
         payload = {
             "method": "server.ping",
@@ -50,22 +74,26 @@ class Hotbit:
         for market in self.marketList():
             self.marketPrecision[market["name"]] = market["money_prec"]
 
-
     def wsGet(self, wsUrl, session, headers={}, encryption=None, identifiers=None, timeout=None, debug=False):
         try:
-            return session.get(wsUrl, headers=headers, encryption=encryption, identifiers=identifiers, timeout=timeout, debug=debug)
+            return session.get(wsUrl, headers=headers, encryption=encryption, identifiers=identifiers, timeout=timeout,
+                               debug=debug)
         except Exception:
             session.wsData = {"CURRENT_URL": None}
             session.post('wss://ws.hotbit.io/', json=self.openingPayload, encryption="gzip", identifiers={"id": 300})
-            return session.post(wsUrl, headers=headers, encryption=encryption, data=data, json=json, waitForResponse=waitForResponse, identifiers=identifiers, timeout=timeout, debug=debug)
+            return session.post(wsUrl, headers=headers, encryption=encryption, data=data, json=json,
+                                waitForResponse=waitForResponse, identifiers=identifiers, timeout=timeout, debug=debug)
 
-    def wsPost(self, wsUrl, session, headers={}, encryption=None, data=None, json=None, waitForResponse=True, identifiers=None, timeout=None, debug=False):
+    def wsPost(self, wsUrl, session, headers={}, encryption=None, data=None, json=None, waitForResponse=True,
+               identifiers=None, timeout=None, debug=False):
         try:
-            return session.post(wsUrl, headers=headers, encryption=encryption, data=data, json=json, waitForResponse=waitForResponse, identifiers=identifiers, timeout=timeout, debug=debug)
+            return session.post(wsUrl, headers=headers, encryption=encryption, data=data, json=json,
+                                waitForResponse=waitForResponse, identifiers=identifiers, timeout=timeout, debug=debug)
         except Exception:
             session.wsData = {"CURRENT_URL": None}
             session.post('wss://ws.hotbit.io/', json=self.openingPayload, encryption="gzip", identifiers={"id": 300})
-            return session.post(wsUrl, headers=headers, encryption=encryption, data=data, json=json, waitForResponse=waitForResponse, identifiers=identifiers, timeout=timeout, debug=debug)
+            return session.post(wsUrl, headers=headers, encryption=encryption, data=data, json=json,
+                                waitForResponse=waitForResponse, identifiers=identifiers, timeout=timeout, debug=debug)
 
     def serverTime(self):
         payload = {
@@ -73,7 +101,8 @@ class Hotbit:
             "params": [],
             "id": 10
         }
-        resp = self.wsPost('wss://ws.hotbit.io/', self.sessionWS, json=payload, encryption="gzip", identifiers={"id": 10})
+        resp = self.wsPost('wss://ws.hotbit.io/', self.sessionWS, json=payload, encryption="gzip",
+                           identifiers={"id": 10})
         return resp.json()
 
     def stateSubscribeall(self, receiver):
@@ -94,7 +123,8 @@ class Hotbit:
             "method": "balance.query",
             "params": []
         }
-        resp = self.wsPost('wss://ws.hotbit.io/', self.sessionWS, json=payload, encryption="gzip", identifiers={"id": 405})
+        resp = self.wsPost('wss://ws.hotbit.io/', self.sessionWS, json=payload, encryption="gzip",
+                           identifiers={"id": 405})
         return resp.json()
 
     def depthQuery(self, market, interval="1e-8", limit=100):
@@ -108,7 +138,8 @@ class Hotbit:
             ],
             "id": 20
         }
-        resp = self.wsPost('wss://ws.hotbit.io/', self.sessionWS, json=payload, encryption="gzip", identifiers={"id": 20})
+        resp = self.wsPost('wss://ws.hotbit.io/', self.sessionWS, json=payload, encryption="gzip",
+                           identifiers={"id": 20})
         return resp.json()
 
     def orderQuery(self, offset=0, limit=50):
@@ -121,7 +152,8 @@ class Hotbit:
             ],
             "id": 13
         }
-        resp = self.wsPost('wss://ws.hotbit.io/', self.sessionWS, json=payload, encryption="gzip", identifiers={"id": 13})
+        resp = self.wsPost('wss://ws.hotbit.io/', self.sessionWS, json=payload, encryption="gzip",
+                           identifiers={"id": 13})
         return resp.json()
 
     def marketPrice(self, market, side, amount=0):
@@ -135,7 +167,8 @@ class Hotbit:
             ],
             "id": 20
         }
-        resp = self.wsPost('wss://ws.hotbit.io/', self.sessionWS, json=payload, encryption="gzip", identifiers={"id": 20})
+        resp = self.wsPost('wss://ws.hotbit.io/', self.sessionWS, json=payload, encryption="gzip",
+                           identifiers={"id": 20})
         if side.lower() == "buy":
             asks = resp.json()["result"]["asks"]
             _amount = 0
@@ -180,7 +213,8 @@ class Hotbit:
             "market": market.upper(),
             "order_id": order_id
         }
-        resp = self.session.post("https://www.hotbit.pro/v1/order/cancel?platform=web", headers=self.defaultHeaders, data=payload)
+        resp = self.session.post("https://www.hotbit.io/v1/order/cancel?platform=web", headers=self.defaultHeaders,
+                                 data=payload, cookies=self.cookies)
         return resp.json()
 
     def order(self, price, amount, market, side, type="LIMIT", hide=False, use_discount=False):
@@ -199,16 +233,17 @@ class Hotbit:
             "hide": hide,
             "use_discount": use_discount
         }
-        resp = self.session.post("https://www.hotbit.pro/v1/order/create?platform=web", headers=self.defaultHeaders, data=payload)
+        resp = self.session.post("https://www.hotbit.io/v1/order/create?platform=web", headers=self.defaultHeaders,
+                                 cookies=self.cookies, data=payload)
         return resp.json()
-    
+
     def priceQuery(self, market):
         market = market.replace("/", "")
 
         payload = {
-            "method":"price.query",
-            "params":[market],
-            "id":100
+            "method": "price.query",
+            "params": [market],
+            "id": 100
         }
 
         resp = self.sessionWS.post(
@@ -219,11 +254,15 @@ class Hotbit:
         )
         return resp.json()
 
-    def fetchOrderHistory(self, since):
-        end_time = int(time.time())   #current time
-        start_time = end_time - since*60   #current time - e.g 10min, It fetches all Orders in the last 10min
-        payload = {}
-        resp = self.session.get(f'https://www.hotbit.io/v1/order/history?start_time={start_time}&end_time={end_time}&page=1&page_size=20&platform=web', headers=self.defaultHeaders, data=payload)
+    def fetchTradeHistory(self, market, limit, last_id=0):
+        payload = {
+            "market": market,
+            "limit": limit,
+            "last_id": last_id
+        }
+        resp = self.session.post(
+            f'https://api.hotbit.io/api/v1/market.deals?market={market}&limit={limit}&last_id={last_id}', data=payload,
+            headers=self.defaultHeaders, cookies=self.cookies)
         return resp.json()
 
     def customWS(self, whatToSend):
